@@ -358,7 +358,8 @@ set_deb_file (GFile * gfile, DVContents *deb)
 		deb->ghandle = gfile;
 	filename = g_file_get_uri (deb->ghandle);
 	if ((!g_str_has_suffix(filename, ".deb")) &&
-		(!g_str_has_suffix(filename, ".udeb")))
+		(!g_str_has_suffix(filename, ".udeb")) &&
+		(!g_str_has_suffix(filename, ".tdeb")))
 		return;
 	deb->filename = filename;
 	deb->ghandle = gfile;
@@ -490,7 +491,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 	bytesread = g_input_stream_read (deb->stream, versionbuf, strlen(ARMAG), NULL, &result);
 	if (result)
 	{
-		g_warning (result->message);
+		g_warning ("%s", result->message);
 		g_clear_error (&result);
 		return FALSE;
 	}
@@ -502,7 +503,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 		g_input_stream_close (deb->stream, NULL, &result);
 		if (result)
 		{
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 		}
 		return FALSE;
@@ -518,14 +519,14 @@ prepare_contents (GFile * gfile, DVContents * deb)
 		g_input_stream_close (deb->stream, NULL, &result);
 		if (result)
 		{
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 		}
 		return FALSE;
 	}
 	if (result)
 	{
-		g_warning (result->message);
+		g_warning ("%s", result->message);
 		g_clear_error (&result);
 	}
 	memberlen = parseheaderlength (debian_binary.ar_size, 
@@ -537,7 +538,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 	bytesread = g_input_stream_read (deb->stream, infobuf, memberlen + (memberlen & 1), NULL, &result);
 	if (result)
 	{
-		g_warning (result->message);
+		g_warning ("%s", result->message);
 		g_clear_error (&result);
 	}
 	g_free (infobuf);
@@ -545,7 +546,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 	bytesread = g_input_stream_read (deb->stream, &controlgz, sizeof (struct ar_hdr), NULL, &result);
 	if (result)
 	{
-		g_warning (result->message);
+		g_warning ("%s", result->message);
 		g_clear_error (&result);
 	}
 	deb->current = &controlgz;
@@ -562,7 +563,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 		g_input_stream_close (deb->stream, NULL, &result);
 		if (result)
 		{
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 		}
 		return FALSE;
@@ -615,7 +616,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 			dv_show_error (DV_ERR_CORRUPT_FILE, deb->parent);
 			deb->ar_message = archive_error_string (deb->control_tar);
 			g_input_stream_close (deb->stream, NULL, &result);
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 			return FALSE;
 		}
@@ -641,7 +642,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 		g_input_stream_close (deb->stream, NULL, &result);
 		if (result)
 		{
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 		}
 	}
@@ -700,7 +701,7 @@ prepare_contents (GFile * gfile, DVContents * deb)
 	g_input_stream_close (deb->stream, NULL, &result);
 	if (result)
 	{
-		g_warning (result->message);
+		g_warning ("%s", result->message);
 		g_clear_error (&result);
 	}
 	return TRUE;
@@ -850,7 +851,7 @@ open_deb (DVContents * deb)
 			G_FILE_QUERY_INFO_NONE, NULL, &result);
 		if (result)
 		{
-			g_warning (result->message);
+			g_warning ("%s", result->message);
 			g_clear_error (&result);
 		}
 		if (0 == g_file_info_get_attribute_uint64 (ginfo,
