@@ -31,7 +31,7 @@
 #include "dvpreview.h"
 #include "support.h"
 
-/* location of key file in user home */
+/* location of key file in xdg_config */
 #define DVKEYDIR ".deb-gview"
 /* name of key file in location. */
 #define DVKEYFILE "preview"
@@ -102,8 +102,8 @@ create_groups (GKeyFile * kf, const gchar * keyfile)
 	/* Translators: This text is much easier to read with
 	a space after each newline */
 	comment = g_strconcat (_(" deb-gview can use this "
-	"dot-file in your home directory \n "
-	"(~/.deb-gview/preview) to specify which applications "
+	"dot-file in your XDG config directory (default: \n "
+	"~/.config/deb-gview/preview) to specify which applications "
 	"should\n be used to preview files from the package.\n "
 	"You are free to edit this file, deb-gview will\n "
 	"not modify it, although it will be replaced if it is\n "
@@ -252,25 +252,35 @@ parse_groups (GKeyFile * kf, gchar **groups, const gchar * keyfile)
 gboolean
 preview_init (void)
 {
-	const gchar * home;
-	gchar * path, * file;
+	const gchar * home, * xdg;
+	gchar * path, * file, * xdg_file;
 	gchar **groups;
 	GKeyFile * kf;
 	GError * gerr;
 	gboolean success;
 
 	gerr = NULL;
-	home = g_get_home_dir ();
-	path = g_strconcat (home, "/", DVKEYDIR, NULL);
+	kf = g_key_file_new ();
+	/* xdg is the new default location. */
+	xdg = g_get_user_config_dir ();
+	path = g_build_filename (xdg, PACKAGE, NULL);
 	if (!g_file_test (path, G_FILE_TEST_IS_DIR))
 		g_mkdir_with_parents (path, 0755);
-	kf = g_key_file_new ();
-	file = g_strconcat (path, "/", DVKEYFILE, NULL);
+	xdg_file = g_build_filename (xdg, PACKAGE, DVKEYFILE, NULL);
+	/* if our file exists in the old home, migrate to xdg. */
+	home = g_get_home_dir ();
+	file = g_strconcat (home, "/", DVKEYDIR, "/", DVKEYFILE, NULL);
+	if (g_file_test (file, G_FILE_TEST_IS_REGULAR))
+		g_rename (file, xdg_file);
+	g_free (file);
+	file = g_build_filename (xdg, PACKAGE, DVKEYFILE, NULL);
 	success = g_key_file_load_from_file (kf, file, G_KEY_FILE_KEEP_COMMENTS, &gerr);
 	groups = g_key_file_get_groups (kf, NULL);
 	success = parse_groups (kf, groups, file);
 	if (g_strv_length(groups) > 0)
 		g_strfreev (groups);
+	g_free (path);
+	g_free (file);
 	return success;
 }
 
