@@ -69,7 +69,7 @@ create_aboutdialog (void)
 
 	aboutdialog = gtk_about_dialog_new ();
 	gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (aboutdialog), VERSION);
-	gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (aboutdialog), _("deb-gview"));
+	gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG (aboutdialog), _("deb-gview"));
 	gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (aboutdialog),
 		"Copyright 2006-2008 Neil Williams <linux@codehelp.co.uk>,\n1994,1995 Ian Jackson <ian@chiark.greenend.org.uk>");
 	gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (aboutdialog),
